@@ -1,6 +1,7 @@
 import logging
 import threading
 import socket
+import errno
 import time
 from .request import CommandMode, Request
 
@@ -18,13 +19,16 @@ class HottohRemoteClient:
     on_disconnect = None
     _info = None
     _data = None
+    _data2 = None
+    _raw = None
     _write_request = False
-    _write_parameters = None
+    _write_parameters = []
     _disconnect_request = False
     socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
-    def __init__(self, address="192.168.4.10", port=5001):
+    def __init__(self, address="192.168.4.10", port=5001, id=0):
         """Create tcp client."""
+        self.id = id
         self.address = address
         self.port = port
         self.log = logging.getLogger(__name__)
@@ -70,53 +74,80 @@ class HottohRemoteClient:
         self.socket.close()
         self.was_connected = False
         self._disconnect_request = False
+        self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
     def _get_data(self, command, parameters):
-        request = Request(command=command, parameters=parameters)
+        request = Request(command=command, parameters=parameters, id=self.id)
         self.socket.send(request.getRequest())
         data = self.socket.recv(1024)
         return self._extractData(f"{data}")
 
     def _set_data(self, parameters):
-        request = Request(command="DAT", mode="W", parameters=parameters)
+        request = Request(command="DAT", mode="W", parameters=parameters, id=self.id)
         self.socket.send(request.getRequest())
         data = self.socket.recv(1024)
         return self._extractData(f"{data}")
+    
+    def _set_raw(self, command, mode, parameters):
+        request = Request(command=command, mode=mode, parameters=parameters, id=self.id)
+        print(request.getRequest())
+        self.socket.send(request.getRequest())
+        data = self.socket.recv(1024)
+        print(data)
+        return self._extractData(f"{data}")
 
     def _open_connection(self):
         if not self.was_connected:
             self.log.debug("Connection was_connected %s", self.was_connected)
-            self.socket.connect((self.address, self.port))
-            self.was_connected = True
-            
+            try:
+                self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                self.socket.connect((self.address, self.port))
+                self.was_connected = True
+            except socket.error as error:
+                if error.errno == errno.EISCONN:
+                    self.log.debug("Socket already connected to %s", self.address)
+                    self._disconnect()
+                    # time.sleep(2)
+                    # self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                    # self.socket.connect((self.address, self.port))
+                    self.was_connected = False
+                    raise error
+                else:
+                    raise error
+
             self._thread.daemon = True
             self._thread.start()
             
-
-
     def _extractData(self, data):
         # Split data to an array
         return data.split(";")
 
     def sendCommand(self, parameters):
         self._write_request = True
-        self._write_parameters = parameters
+        self._write_parameters.append(parameters)
         return True
 
     def loop(self):
         while not self._disconnect_request:
             try:
+                # self._raw = self._set_raw("BRQ", "E", ["\"95.110.247.27\"", "47067"])
                 # Get info
                 self._info = self._get_data("INF", [""])
                 # self.log.debug("Information Data %s", self._info)
                 # Get Data
                 self._data = self._get_data("DAT", ["0"])
                 # self.log.debug("Information Data %s", self._data)
+                self._data2 = self._get_data("DAT", ["2"])
                 # Write if needed
-                if self._write_request:
-                    self.log.debug("Send Command %s", self._write_parameters)
-                    res = self._set_data(self._write_parameters)
-                    self._write_request = False
+                while len(self._write_parameters):
+                    param = self._write_parameters[0]
+                    self.log.debug("Send Command %s", param)
+                    res = self._set_data(param)
+                    self.log.debug("Get Response command %s", res)
+                    self._write_parameters.remove(param)
+
+                self._write_parameters = []
+                self._write_request = False
                 
                 time.sleep(1)
             except socket.error as exc:
